// Crimson Fields -- a game of tactical warfare
// Copyright (C) 2000-2003 Jens Granseuer
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//

///////////////////////////////////////////////////////////////
// initwindow.h
//
// Changes:
//   08-11-2001 - windows are subclasses of ButtonHook; this
//                removes the need for a separate hook class
//                for each window
//   16-06-2002 - added class LevTextListWidget
//   23-06-2002 - added TitleWindow
///////////////////////////////////////////////////////////////

#ifndef _INCLUDE_INITWINDOW_H
#define _INCLUDE_INITWINDOW_H

#include <string>
using namespace std;

#include "window.h"
#include "textbox.h"
#include "button.h"

class LevListWidget : public TextListWidget {
public:
  LevListWidget( short id, short x, short y, unsigned short w,
    unsigned short h, List *list, short selected,
    unsigned short flags, const char *title, Window *window ) :
    TextListWidget( id, x, y, w, h, list, selected, flags, title, window ) {};

  void PrintItem( const TLWNode *item, Surface *dest,
                  short x, short y, const Rect &clip ) const;
};


class TitleWindow : public Window {
public:
  TitleWindow( View *view );

  GUI_Status HandleEvent( const SDL_Event &event );
  void Draw( void ) {}
};

class InitWindow : public Window, public ButtonHook {
public:
  InitWindow( View *view, Window *title );
  ~InitWindow( void );

  void Draw( void );
  void Close( void ) { Window::Close(); view->CloseWindow(title); }
  GUI_Status Activate( ButtonWidget *button, Window *win );

private:
  void CompleteFilesList( TLWList &list ) const;

  TextListWidget *levwidget;
  ButtonWidget *startwidget;
  ButtonWidget *listctrlwidget;
  ButtonWidget *videowidget;
  CheckboxWidget *pbemwidget;
  CheckboxWidget *aiwidget;

  TLWList levels;
  TLWList saves;

  Window *title;
};

class VideoOptionsWindow : public Window, public ButtonHook {
public:
  VideoOptionsWindow( View *view );

  void Draw( void );
  GUI_Status Activate( ButtonWidget *button, Window *win );

private:
  TextListWidget *modewidget;
  CheckboxWidget *fswidget;

  List modes;
};

#endif	/* _INCLUDE_INITWINDOW_H */

