// Crimson Fields -- a game of tactical warfare
// Copyright (C) 2000-2003 Jens Granseuer
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//

////////////////////////////////////////////////////////////////////////
// aux.cpp
//
// History:
//  16-03-2003 - created
////////////////////////////////////////////////////////////////////////

#include "aux.h"
#include "mission.h"

////////////////////////////////////////////////////////////////////////
// NAME       : TLWListBuilder::BuildEventList
// DESCRIPTION: Use the events list to create a second list which can
//              be displayed by a TextListWidget.
// PARAMETERS : events - list of events
//              tlw    - list of TLWNodes to be filled
// RETURNS    : -
//
// HISTORY
////////////////////////////////////////////////////////////////////////

void TLWListBuilder::BuildEventList( const List &events, TLWList &tlw ) {
  for ( Event *e = static_cast<Event *>( events.Head() ); e;
        e = static_cast<Event *>(e->Next()) ) {
    char buf[48];
    sprintf( buf, "%s (%d)", e->Name(), e->ID() );
    tlw.InsertNodeSorted( new TLWNode(buf, e) );
  }
}

////////////////////////////////////////////////////////////////////////
// NAME       : TLWListBuilder::BuildUnitList
// DESCRIPTION: Use the units list to create a second list which can
//              be displayed by a TextListWidget.
// PARAMETERS : events - list of units
//              tlw    - list of TLWNodes to be filled
// RETURNS    : -
//
// HISTORY
////////////////////////////////////////////////////////////////////////

void TLWListBuilder::BuildUnitList( const List &units, TLWList &tlw ) {
  for ( Unit *u = static_cast<Unit *>( units.Head() ); u;
        u = static_cast<Unit *>(u->Next()) ) {
    char buf[28];
    sprintf( buf, "%s (%d)", u->Name(), u->ID() );
    tlw.InsertNodeSorted( new TLWNode(buf, u) );
  }
}

////////////////////////////////////////////////////////////////////////
// NAME       : TLWListBuilder::BuildShopList
// DESCRIPTION: Use the buildings list to create a second list which can
//              be displayed by a TextListWidget.
// PARAMETERS : events - list of buildings
//              tlw    - list of TLWNodes to be filled
// RETURNS    : -
//
// HISTORY
////////////////////////////////////////////////////////////////////////

void TLWListBuilder::BuildShopList( const List &shops, TLWList &tlw ) {
  for ( Building *b = static_cast<Building *>( shops.Head() ); b;
        b = static_cast<Building *>(b->Next()) ) {
    char buf[28];
    sprintf( buf, "%s (%d)", b->Name(), b->ID() );
    tlw.InsertNodeSorted( new TLWNode(buf, b) );
  }
}

